.. gros_client_py_markdown documentation master file, created by
   sphinx-quickstart on Fri Sep  8 17:03:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gros_client_py_markdown's documentation!
===================================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   markdown_conf
   setup
   src
   test


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
